import quilt3

from prefect import task


@task
def load_quilt_package(quilt_package: str, quilt_registry: str) -> quilt3.Package:
    package = quilt3.Package.browse(quilt_package, quilt_registry)
    return package



import io

import quilt3
from prefect import task

from io_collection.save import save_buffer


@task
def save_quilt_item(location: str, key: str, package: quilt3.Package, item: str) -> None:
    contents = package[item].get_bytes()
    buffer = io.BytesIO(contents)
    save_buffer.fn(location, key, buffer)



import os

from prefect import task
from aicsimageio import AICSImage
from aicsimageio.readers import OmeTiffReader, TiffReader


@task
def load_image(location: str, key: str) -> AICSImage:
    if location[:5] == "s3://":
        return load_image_from_s3(location[5:], key)
    else:
        return load_image_from_fs(location, key)


def load_image_from_fs(path: str, key: str) -> AICSImage:
    full_path = os.path.join(path, key)
    return AICSImage(full_path, reader=OmeTiffReader if key.endswith(".ome.tiff") else TiffReader)


def load_image_from_s3(bucket: str, key: str) -> AICSImage:
    full_key = f"s3://{bucket}/{key}"
    return AICSImage(full_key, reader=OmeTiffReader if key.endswith(".ome.tiff") else TiffReader)
